$NetBSD: patch-ab,v 1.1.1.1 2006/02/14 17:03:54 rillig Exp $

--- src/main.c.orig	Tue Jul  9 05:53:49 2002
+++ src/main.c	Sun Jan 26 18:12:54 2003
@@ -109,12 +109,12 @@
 }
 			
 
 /* writepid() - Writes the current pid to game.pidfile */
 void writepid(void)
   {
     FILE *file_out;
     
-    file_out = fopen(game.pidfile,"w");
+    file_out = fopen(FILE_PID,"w");
     if (file_out == NULL)
       {
         // lvprintf(0,"ERROR: Could not write to PID file %s\n", game.pidfile);
@@ -129,7 +129,7 @@
 /* delpid() - Delete the pid file */
 void delpid(void)
   {
-    remove(game.pidfile);
+    remove(FILE_PID);
   }
 
 /* int numallplayers(chan) - Returns ANY player that is connected in a channel */
@@ -4695,7 +4695,7 @@
   {
     struct sigaction sv;
     
-    lvprintf(0,"\nTetriNET for Linux V%s.%s\n---------------------------------\n", TETVERSION, SERVERBUILD);
+    lvprintf(0,"\nTetriNET for NetBSD V%s.%s\n---------------------------------\n", TETVERSION, SERVERBUILD);
     
 
     gnet=NULL;
@@ -109,12 +109,12 @@
 			
 
-/* writepid() - Writes the current pid to game.pidfile */
+/* writepid() - Writes the current pid to FILE_PID */
 void writepid(void)
   {
